==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/URLPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour URLPARAMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="URLPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONTABID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}URLPARAMETERNAME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "URLPARAMETERID_Type", propOrder = {
    "functiontabid",
    "urlparametername"
})
public class URLPARAMETERID_Type {

    @XmlElement(name = "FUNCTIONTABID", required = true)
    protected FUNCTIONTABID_Type functiontabid;
    @XmlElement(name = "URLPARAMETERNAME", required = true)
    protected String urlparametername;

    /**
     * Obtient la valeur de la propriété functiontabid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public FUNCTIONTABID_Type getFUNCTIONTABID() {
        return functiontabid;
    }

    /**
     * Définit la valeur de la propriété functiontabid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public void setFUNCTIONTABID(FUNCTIONTABID_Type value) {
        this.functiontabid = value;
    }

    /**
     * Obtient la valeur de la propriété urlparametername.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getURLPARAMETERNAME() {
        return urlparametername;
    }

    /**
     * Définit la valeur de la propriété urlparametername.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setURLPARAMETERNAME(String value) {
        this.urlparametername = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/URLPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for URLPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="URLPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONTABID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}URLPARAMETERNAME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "URLPARAMETERID_Type", propOrder = {
    "functiontabid",
    "urlparametername"
})
public class URLPARAMETERID_Type {

    @XmlElement(name = "FUNCTIONTABID", required = true)
    protected FUNCTIONTABID_Type functiontabid;
    @XmlElement(name = "URLPARAMETERNAME", required = true)
    protected String urlparametername;

    /**
     * Gets the value of the functiontabid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public FUNCTIONTABID_Type getFUNCTIONTABID() {
        return functiontabid;
    }

    /**
     * Sets the value of the functiontabid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public void setFUNCTIONTABID(FUNCTIONTABID_Type value) {
        this.functiontabid = value;
    }

    /**
     * Gets the value of the urlparametername property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getURLPARAMETERNAME() {
        return urlparametername;
    }

    /**
     * Sets the value of the urlparametername property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setURLPARAMETERNAME(String value) {
        this.urlparametername = value;
    }

}
